==> knowledge-center-api-0.4.0-remould-20181009.080352-22-sources.jar: cn/yoofans/knowledge/center/api/remoteservice/RemoteUserPlaybackProgressService.java <==
/**
 * Copyright (C), 2015-2018, XXX有限公司
 * FileName: RemoteUserPlaybackProgressService
 * Author:   amu
 * Date:     2018/4/27 下午7:41
 * Description:
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package cn.yoofans.knowledge.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.yoofans.knowledge.center.api.dto.UserPlaybackProgressDTO;
import cn.yoofans.knowledge.center.api.param.RemotePlayProgressParams;
import cn.yoofans.knowledge.center.api.param.UserPlayProgressParams;
import cn.yoofans.knowledge.center.api.param.playprogress.UserPlayFinishParams;

import java.util.List;

/**
 * 〈一句话功能简述〉<br> 
 * 〈〉
 *
 * @author amu
 * @create 2018/4/27
 * @since 1.0.0
 */
@AdvancedFeignClient
public interface RemoteUserPlaybackProgressService {

    /**
     * 按照客户和专栏id查询
     *
     * @return
     */
    List<UserPlaybackProgressDTO> findByConsumerIdAndColumnId(RemotePlayProgressParams remotePlayProgressParams);


    /**
     * 更新用户已购播放进度
     * @param userPlayProgressParams
     * @return
     */

    Boolean updatePlayBackProgress(UserPlayProgressParams userPlayProgressParams);

    /**
     * 更新完课状态
     * @param params
     * @return
     */
    Boolean updateFinishState(UserPlayFinishParams params);

    Long findNoStudyDays(Long cid, Long readId);

    /**
     * 根据用户ID、计划ID和课程ID获取信息
     * @param cid
     * @param readId
     * @param courseId
     * @return
     */
    List<UserPlaybackProgressDTO> findByCidAndReadIdAndCourseId(Long cid, Long readId, Long courseId);

    /**
     * 查询完课和补完课数量
     * @param cid
     * @param readId
     * @return
     */
    Long findFinishClassCount(Long cid, Long readId);
}

==> knowledge-center-api-0.4.5-remould-20181017.060323-1-sources.jar: cn/yoofans/knowledge/center/api/remoteservice/RemoteUserPlaybackProgressService.java <==
/**
 * Copyright (C), 2015-2018, XXX有限公司
 * FileName: RemoteUserPlaybackProgressService
 * Author:   amu
 * Date:     2018/4/27 下午7:41
 * Description:
 * History:
 * <author>          <time>          <version>          <desc>
 * 作者姓名           修改时间           版本号              描述
 */
package cn.yoofans.knowledge.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.yoofans.knowledge.center.api.dto.UserPlaybackProgressDTO;
import cn.yoofans.knowledge.center.api.param.RemotePlayProgressParams;
import cn.yoofans.knowledge.center.api.param.UserPlayProgressParams;
import cn.yoofans.knowledge.center.api.param.playprogress.UserPlayFinishParams;

import java.util.List;

/**
 * 〈一句话功能简述〉<br>
 * 〈〉
 *
 * @author amu
 * @create 2018/4/27
 * @since 1.0.0
 */
@AdvancedFeignClient
public interface RemoteUserPlaybackProgressService {

    /**
     * 按照客户和专栏id查询
     *
     * @return
     */
    List<UserPlaybackProgressDTO> findByConsumerIdAndColumnId(RemotePlayProgressParams remotePlayProgressParams);

    /**
     * 更新用户已购播放进度
     *
     * @param userPlayProgressParams
     * @return
     */

    Boolean updatePlayBackProgress(UserPlayProgressParams userPlayProgressParams);

    /**
     * @author zhangmm
     * @Description: 统计用户收听总时长
     * @date 2018/10/10 0010 16:14
    */
    public Boolean updatePlayBackProgressForCount(UserPlayProgressParams params);
        /**
         * 更新完课状态
         *
         * @param params
         * @return
         */
    Boolean updateFinishState(UserPlayFinishParams params);

    /**
     * 请使用新接口 findNoStudyDaysStageId
     *
     * @param cid
     * @param readId
     * @return
     */
    @Deprecated
    Long findNoStudyDays(Long cid, Long readId);

    /**
     * 查询未学完天数
     *
     * @param cid
     * @param readId
     * @param stageId
     * @return
     */
    Long findNoStudyDaysStageId(Long cid, Long readId, Long stageId);
	
	/**
     * 根据用户ID、计划ID和课程ID获取信息
     * @param cid
     * @param readId
     * @param courseId
     * @return
     */
    List<UserPlaybackProgressDTO> findByCidAndReadIdAndCourseId(Long cid, Long readId, Long courseId);

    /**
     * 修改用户播放进度
     * @return
     */
    Boolean fixUserPlayBackProgress(Long readId,Long courseId,String startTime,String endTime,Long id,Integer finishStatus);

    /**
     * 依据用户id查询用户所有的播放进度
     *
     * @param userId
     * @return
     */
    List<UserPlaybackProgressDTO> findListByUserAndRead(Long userId, Long readId);
	
	/**
     * 查询完课和补完课数量
     * @param cid
     * @param readId
     * @return
     */
    Long findFinishClassCount(Long cid, Long readId);

    /**
     * 根据阅读计划ID、课程ID、期数ID获取第一个完课的用户ID
     * @param readId
     * @param courseId
     * @param readStageId
     * @return
     */
    Long findFirstFinishUserId(Long readId, Long courseId,Long readStageId);

    /**
     * 根据阅读计划ID、课程ID、期数ID获取完课人数
     * @param readId
     * @param courseId
     * @param readStageId
     * @return
     */
    Long findFinishCountByReadStageCourse(Long readId, Long courseId,Long readStageId);
}
